Class CassandraSchemaElementExistsException

All Implemented Interfaces:
Serializable
Direct Known Subclasses:
CassandraKeyspaceExistsException, CassandraTableExistsException

public class CassandraSchemaElementExistsException extends NonTransientDataAccessException
Spring data access exception for when Cassandra schema element being created already exists.
Author:
Matthew T. Adams, Mark Paluch
See Also:
  • Constructor Details

    • CassandraSchemaElementExistsException

      public CassandraSchemaElementExistsException(String msg, Throwable cause)
      Parameters:
      msg - the detail message.
      cause - the root cause from the underlying data access API.