Class CassandraSchemaElementExistsException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.springframework.core.NestedRuntimeException
org.springframework.dao.DataAccessException
org.springframework.dao.NonTransientDataAccessException
org.springframework.data.cassandra.CassandraSchemaElementExistsException
- All Implemented Interfaces:
Serializable
- Direct Known Subclasses:
CassandraKeyspaceExistsException, CassandraTableExistsException
Spring data access exception for when Cassandra schema element being created already exists.
- Author:
- Matthew T. Adams, Mark Paluch
- See Also:
-
Constructor Summary
ConstructorsConstructorDescriptionCassandraSchemaElementExistsException(String msg, Throwable cause) Constructor forCassandraSchemaElementExistsException. -
Method Summary
Methods inherited from class NestedRuntimeException
contains, getMostSpecificCause, getRootCauseMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
CassandraSchemaElementExistsException
Constructor forCassandraSchemaElementExistsException.- Parameters:
msg- the detail message.cause- the root cause from the underlying data access API.
-